# pyacp



## Getting started

## install pyacp command:
1. cd pyacp
2.sudo python3 setup.py build
3.sudo python3 setup.py install
OK
## test:
0. python3 example/server.py  //if you have plchandler,please dont use this script
1. python3 example/client_read.py
2. python3 example/client_write.py

